@@ -115,7 +115,13 @@ else {
                         false));
     }
 }
-$App->setSkin($App->getConfig('SKINDIR','default'),$header_template);
+
+if (preg_match('/admin.php/',$_SERVER['SCRIPT_FILENAME'])) {
+    $App->setSkin($App->getConfig('SKINDIR','admin'),$header_template);
+}
+else {                          // user templates
+    $App->setSkin($App->getConfig('SKINDIR','user'),$header_template);
+}
 
 // fetch user variable from session
 $USER = $App->getSession('USER');
