@@ -282,7 +282,7 @@ class Application extends ApplicationConfig
      * @param array $_REQUEST request parameters
      * @return object
      */
-    function Application ($configfile,$request,$MODULE)
+    function __construct($configfile,$request,$MODULE)
     {
 
         $this->_debug_vars = array();
