@@ -103,7 +103,7 @@ class DBAccess
      * @param string $host (optional)
      * @param string $database (optional)
      */
-    function DBAccess ($dbType,$dbUser='',$dbPassword='',$host='',$database='')
+    function __construct($dbType,$dbUser='',$dbPassword='',$host='',$database='')
     {
 
         $this->error = FALSE;
