@@ -43,8 +43,10 @@ $userid = $login['username']; // fetch masked parameter (DB access)
 $passwd = $_REQUEST['login']['password']; // fetch PW raw
 //$passwd = $login['password'];
 
+$redata['selectuser'] = $userid;
 if (! $passwd) {
-    $App->redirect('default',array('MSG'=>'ERR_NOPASS'));
+    $redata['MSG'] = 'ERR_NOPASS';
+    $App->redirect('default',$redata);
 }
 
 $RESTconf = new ApplicationConfig($App->configdir);
@@ -68,15 +70,17 @@ try {
         // check authentication
         if ($USER->password != md5($passwd)) {
             // Authentication error -> redirect to login
+            $redata['MSG'] = 'ERR_AUTH';
             $App->log('Authentication of '.$USER->id.' failed');
-            $App->redirect('default',array('MSG'=>'ERR_AUTH'));
+            $App->redirect('default',$redata);
         }
     }
 }
 catch (Exception $e) {
     $exc = $e->getMessage();
     $App->log('Authentication error: '.$exc);
-    $App->redirect('default',array('MSG'=>$exc));
+    $redata['MSG'] = $exc;
+    $App->redirect('default',$redata);
 }
 
 // LOGIN SUCCESSFUL
@@ -156,10 +160,6 @@ $App->setSession('Backend',$Backend);   // store backend for this session
 $App->setSession('archive',$archive);   // store current archive
 $App->setSession('FilterList',$FilterList);
 
-if ($USER->getAuthParam('AUTHBY') == 'db') { // show admin ui
-    $App->setSession('USERPANEL',true);
-}
-
 // set language on change and after login for 32 days
 setcookie("BENNO_LANGUAGE", $LANG, time()+2764800, dirname($_SERVER['REQUEST_URI']));
 
