@@ -45,7 +45,7 @@ class Backend
     var $rest_pass;
     var $_curl;
 
-    function Backend ($base_url,$rest_user,$rest_pass,$filter)
+    function __construct($base_url,$rest_user,$rest_pass,$filter)
     {
         global $App;
         $this->rest_user = $rest_user;
