@@ -50,10 +50,10 @@ class Benno
      * @access public
      * @return string $info
      */
-    function Benno ()
+    function __construct()
     {
-        $this->infoText = 'Benno MailArchiv Version 2.8.2'; 
-        $this->buildInfo= '191015185215/e736fb3';
+        $this->infoText = 'Benno MailArchiv Version 2.8.3'; 
+        $this->buildInfo= '191211172615/ca056a3';
         $this->buildYear= '2019';
     }
 
