@@ -119,6 +119,17 @@ class User extends UserDA
     var $authparam;
 
 
+   /**
+     * filter
+     *
+     * Additional filters
+     *
+     * @access public
+     * @var array
+     */
+    var $filter;
+
+
     /**
      * constructor
      *
@@ -131,9 +142,10 @@ class User extends UserDA
      * @param array $addresses optional
      * @param array $restdata optional
      * @param array $authparam optional
+     * @param array $filter optional
      * @return object
      */
-    function User ($id,$password='',$name='',$archive=array(),$role='',$adresses=array(),$restdata=array(),$authparam=array())
+    function __construct($id,$password='',$name='',$archive=array(),$role='',$adresses=array(),$restdata=array(),$authparam=array(),$filter=array())
     {
         $this->id = $id;
         $this->password = $password;
@@ -143,6 +155,7 @@ class User extends UserDA
         $this->addresses = $adresses;
         $this->restdata = $restdata;
         $this->authparam = $authparam;
+        $this->filter= $filter;
     }
 
     function getAuthzLevel () {
@@ -157,16 +170,15 @@ class User extends UserDA
         // BNO_STATS     64 statistics
         // BNO_SITEADM  128 admingui (change container,siteadmin role)
 
-        if ($this->role == 'AUTH')      { $level = BNO_AUTH            ;}
-        if ($this->role == 'USER')      { $level = BNO_AUTH | BNO_USER ;}
-        if ($this->role == 'REVISOR')   { $level = BNO_AUTH | BNO_SYSINFO | BNO_SYSDATA ;}
-        if ($this->role == 'USERADMIN') { $level = BNO_AUTH |                             BNO_ADMIN ;}
-        if ($this->role == 'ADMIN')     { $level = BNO_AUTH | BNO_SYSINFO | BNO_SYSDATA | BNO_ADMIN | BNO_STATS ;}
+        if ($this->role == 'AUTH')      { $level = BNO_AUTH ;}
+        if ($this->role == 'USER')      { $level = BNO_AUTH|BNO_USER ;}
+        if ($this->role == 'USERADMIN') { $level = BNO_AUTH|BNO_USER ;}
+        if ($this->role == 'REVISOR')   { $level = BNO_AUTH|BNO_SYSINFO|BNO_SYSDATA ;}
+        if ($this->role == 'ADMIN')     { $level = BNO_AUTH|BNO_SYSINFO|BNO_SYSDATA|BNO_STATS|BNO_ADMIN;}
 
         return $level;
     }
 
-
     function permission($feature) {
         if (is_string($feature)) {      // 'constant' from Smarty template
             $feature = constant($feature);
@@ -193,5 +205,7 @@ class User extends UserDA
 
     function getAuthParam ($param) { return $this->authparam[$param]; }
 
+    function getFilter() { return $this->filter; }
+
 }
 ?>
